4.47. umbra.ui.themes — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.47. umbra.ui.themes

highlighters.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the Application themes classes.

Others:

## 4.47.1. Module Attributes

`umbra.ui.themes.` `LOGGER`

`umbra.ui.themes.` `DEFAULT_FORMAT`

`umbra.ui.themes.` `DEFAULT_THEME`

`umbra.ui.themes.` `LOGGING_THEME`

## 4.47.2. Functions

`umbra.ui.themes.` `getFormat`(**kwargs)

  This definition returns a QTextCharFormat format.

  Parameters: | **kwargs – Format settings. ( Key / Value pairs )
  Returns: | Format. ( QTextCharFormat )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »